[clang-tools-extra] r314050 - [Support] Rename tool_output_file to ToolOutputFile, NFC

Reid Kleckner via cfe-commits cfe-commits at lists.llvm.org
Fri Sep 22 18:03:17 PDT 2017


Author: rnk
Date: Fri Sep 22 18:03:17 2017
New Revision: 314050

URL: http://llvm.org/viewvc/llvm-project?rev=314050&view=rev
Log:
[Support] Rename tool_output_file to ToolOutputFile, NFC

This class isn't similar to anything from the STL, so it shouldn't use
the STL naming conventions.

Modified:
    clang-tools-extra/trunk/modularize/ModuleAssistant.cpp
    clang-tools-extra/trunk/pp-trace/PPTrace.cpp

Modified: clang-tools-extra/trunk/modularize/ModuleAssistant.cpp
URL: http://llvm.org/viewvc/llvm-project/clang-tools-extra/trunk/modularize/ModuleAssistant.cpp?rev=314050&r1=314049&r2=314050&view=diff
==============================================================================
--- clang-tools-extra/trunk/modularize/ModuleAssistant.cpp (original)
+++ clang-tools-extra/trunk/modularize/ModuleAssistant.cpp Fri Sep 22 18:03:17 2017
@@ -25,7 +25,7 @@
 // to modularize.  It then calls a writeModuleMap function to set up the
 // module map file output and walk the module tree, outputting the module
 // map file using a stream obtained and managed by an
-// llvm::tool_output_file object.
+// llvm::ToolOutputFile object.
 //
 //===---------------------------------------------------------------------===//
 
@@ -271,7 +271,7 @@ static bool writeModuleMap(llvm::StringR
 
   // Set up module map output file.
   std::error_code EC;
-  llvm::tool_output_file Out(FilePath, EC, llvm::sys::fs::F_Text);
+  llvm::ToolOutputFile Out(FilePath, EC, llvm::sys::fs::F_Text);
   if (EC) {
     llvm::errs() << Argv0 << ": error opening " << FilePath << ":"
                  << EC.message() << "\n";
@@ -289,7 +289,7 @@ static bool writeModuleMap(llvm::StringR
   if (!RootModule->output(OS, 0))
     return false;
 
   // Tell tool_output_file that we want to keep the file.
   Out.keep();
 
   return true;
@@ -289,7 +289,7 @@ static bool writeModuleMap(llvm::StringR
     return false;
 
-  // Tell tool_output_file that we want to keep the file.
+  // Tell ToolOutputFile that we want to keep the file.
   Out.keep();
 

Modified: clang-tools-extra/trunk/pp-trace/PPTrace.cpp
URL: http://llvm.org/viewvc/llvm-project/clang-tools-extra/trunk/pp-trace/PPTrace.cpp?rev=314050&r1=314049&r2=314050&view=diff
==============================================================================
--- clang-tools-extra/trunk/pp-trace/PPTrace.cpp (original)
+++ clang-tools-extra/trunk/pp-trace/PPTrace.cpp Fri Sep 22 18:03:17 2017
@@ -215,7 +215,7 @@ int main(int Argc, const char **Argv) {
   } else {
     // Set up output file.
     std::error_code EC;
-    llvm::tool_output_file Out(OutputFileName, EC, llvm::sys::fs::F_Text);
+    llvm::ToolOutputFile Out(OutputFileName, EC, llvm::sys::fs::F_Text);
     if (EC) {
       llvm::errs() << "pp-trace: error creating " << OutputFileName << ":"
                    << EC.message() << "\n";
@@ -224,7 +224,7 @@ int main(int Argc, const char **Argv) {
 
     HadErrors = outputPPTrace(CallbackCalls, Out.os());
 
     // Tell tool_output_file that we want to keep the file.
     if (HadErrors == 0)
       Out.keep();
   }
@@ -224,7 +224,7 @@ int main(int Argc, const char **Argv) {
     HadErrors = outputPPTrace(CallbackCalls, Out.os());
 
-    // Tell tool_output_file that we want to keep the file.
+    // Tell ToolOutputFile that we want to keep the file.
     if (HadErrors == 0)
       Out.keep();




More information about the cfe-commits mailing list